@@ -87,17 +87,6 @@ sub SetRecipients {
     my ( @To, @PseudoTo, @Cc, @Bcc );
 
 
-    if ( $arg =~ /\bOtherRecipients\b/ ) {
-        if ( my $attachment = $self->TransactionObj->Attachments->First ) {
-            push @Cc, map { $_->address } Email::Address->parse(
-                $attachment->GetHeader('RT-Send-Cc')
-            );
-            push @Bcc, map { $_->address } Email::Address->parse(
-                $attachment->GetHeader('RT-Send-Bcc')
-            );
-        }
-    }
-
     if ( $arg =~ /\bRequestor\b/ ) {
         push @To, $ticket->Requestors->MemberEmailAddresses;
     }
@@ -162,7 +151,14 @@ sub SetRecipients {
     }
     @{ $self->{'PseudoTo'} } = @PseudoTo;
 
-
+    if ( $arg =~ /\bOtherRecipients\b/ ) {
+        if ( my $attachment = $self->TransactionObj->Attachments->First ) {
+            push @{ $self->{'NoSquelch'}{'Cc'} ||= [] }, map $_->address,
+                Email::Address->parse( $attachment->GetHeader('RT-Send-Cc') );
+            push @{ $self->{'NoSquelch'}{'Bcc'} ||= [] }, map $_->address,
+                Email::Address->parse( $attachment->GetHeader('RT-Send-Bcc') );
+        }
+    }
 }
 
 RT::Base->_ImportOverlays();
