@@ -161,7 +161,7 @@ sub IsSubscriptionReady {
 
     if ($sub_frequency eq 'weekly') {
         # correct day of week?
-        return 0 if $sub_frequency ne $dow;
+        return 0 if $sub_dow ne $dow;
 
         # does it match the "every N weeks" clause?
         $sub_fow = 1 if !$sub_fow;
@@ -318,9 +318,22 @@ sub EmailDashboard {
     my $currentuser  = $args{CurrentUser};
     my $email        = $args{Email};
 
+    my $frequency    = $subscription->SubValue('Frequency');
+
+    my %frequency_lookup = (
+        'm-f'     => 'Weekday', # loc
+        'daily'   => 'Daily',   # loc
+        'weekly'  => 'Weekly',  # loc
+        'monthly' => 'Monthly', # loc
+        'never'   => 'Never',   # loc
+    );
+
+    my $frequency_display = $frequency_lookup{$frequency}
+                         || $frequency;
+
     my $subject = sprintf '[%s] ' .  RT->Config->Get('DashboardSubject'),
         RT->Config->Get('rtname'),
-        ucfirst($subscription->SubValue('Frequency')),
+        $currentuser->loc($frequency_display),
         $dashboard->Name;
 
     my $entity = $self->BuildEmail(
@@ -329,8 +342,8 @@ sub EmailDashboard {
         Subject => $subject,
     );
 
-    $entity->head->add('X-RT-Dashboard-Id', $dashboard->Id);
-    $entity->head->add('X-RT-Dashboard-Subscription-Id', $subscription->Id);
+    $entity->head->replace('X-RT-Dashboard-Id', $dashboard->Id);
+    $entity->head->replace('X-RT-Dashboard-Subscription-Id', $subscription->Id);
 
     $RT::Logger->debug('Mailing dashboard "'.$dashboard->Name.'" to user '.$currentuser->Name." <$email>");
 
