@@ -65,10 +65,8 @@ use File::Glob qw( bsd_glob );
 use File::Spec::Unix;
 
 sub DefaultHandlerArgs  { (
-    comp_root => [
-        [ local    => $RT::MasonLocalComponentRoot ],
-        (map {[ "plugin-".$_->Name =>  $_->ComponentRoot ]} @{RT->Plugins}),
-        [ standard => $RT::MasonComponentRoot ]
+    comp_root            => [
+        RT::Interface::Web->ComponentRoots( Names => 1 ),
     ],
     default_escape_flags => 'h',
     data_dir             => "$RT::MasonDataDir",
@@ -271,6 +269,13 @@ sub _psgi_response_cb {
     Plack::Util::response_cb
             ($ret,
              sub {
+                 my $res = shift;
+
+                 if ( RT->Config->Get('Framebusting') ) {
+                     # XXX TODO: Do we want to make the value of this header configurable?
+                     Plack::Util::header_set($res->[1], 'X-Frame-Options' => 'DENY');
+                 }
+
                  return sub {
                      if (!defined $_[0]) {
                          $cleanup->();
