@@ -57,6 +57,8 @@ use Regexp::IPv6 qw($IPv6_re);
 use Regexp::Common::net::CIDR;
 require Net::CIDR;
 
+# Allow the empty IPv6 address
+$IPv6_re = qr/(?:$IPv6_re|::)/;
 
 
 
