@@ -1,40 +1,40 @@
 # BEGIN BPS TAGGED BLOCK {{{
-# 
+#
 # COPYRIGHT:
-# 
-# This software is Copyright (c) 1996-2009 Best Practical Solutions, LLC
-#                                          <jesse@bestpractical.com>
-# 
+#
+# This software is Copyright (c) 1996-2011 Best Practical Solutions, LLC
+#                                          <sales@bestpractical.com>
+#
 # (Except where explicitly superseded by other copyright notices)
-# 
-# 
+#
+#
 # LICENSE:
-# 
+#
 # This work is made available to you under the terms of Version 2 of
 # the GNU General Public License. A copy of that license should have
 # been provided with this software, but in any event can be snarfed
 # from www.gnu.org.
-# 
+#
 # This work is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 or visit their web page on the internet at
 # http://www.gnu.org/licenses/old-licenses/gpl-2.0.html.
-# 
-# 
+#
+#
 # CONTRIBUTION SUBMISSION POLICY:
-# 
+#
 # (The following paragraph is not intended to limit the rights granted
 # to you to modify and distribute this software under the terms of
 # the GNU General Public License and is only of importance to you if
 # you choose to contribute your changes and enhancements to the
 # community by submitting them to Best Practical Solutions, LLC.)
-# 
+#
 # By intentionally submitting any modifications, corrections or
 # derivatives to this work, or any other work intended for use with
 # Request Tracker, to Best Practical Solutions, LLC, you confirm that
@@ -43,12 +43,13 @@
 # royalty-free, perpetual, license to use, copy, create derivative
 # works based on those contributions, and sublicense and distribute
 # those contributions and any derivatives thereof.
-# 
+#
 # END BPS TAGGED BLOCK }}}
 
 package RT::URI;
 
 use strict;
+use warnings;
 use base 'RT::Base';
 
 use RT::URI::base;
@@ -92,11 +93,10 @@ sub new {
 
 
 
-# {{{ FromObject
 
 =head2 FromObject <Object>
 
-Given a local object, such as an RT::Ticket or an RT::FM::Article, this routine will return a URI for
+Given a local object, such as an RT::Ticket or an RT::Article, this routine will return a URI for
 the local object
 
 =cut
@@ -109,9 +109,7 @@ sub FromObject {
     return $self->FromURI($obj->URI);
 }
 
-# }}}
 
-# {{{ FromURI
 
 =head2 FromURI <URI>
 
@@ -136,6 +134,7 @@ sub FromURI {
 	$scheme = $1;
     }
     else {
+        $self->{resolver} = RT::URI::base->new( $self->CurrentUser ); # clear resolver
         $RT::Logger->warning("Could not determine a URI scheme for $uri");
         return (undef);
     }
@@ -144,7 +143,10 @@ sub FromURI {
     $self->_GetResolver($scheme);
     
     unless ($self->Resolver->ParseURI($uri)) {
-        $RT::Logger->warning("Resolver ".ref($self->Resolver)." could not parse $uri");
+        $RT::Logger->warning( "Resolver "
+              . ref( $self->Resolver )
+              . " could not parse $uri, maybe Organization config was changed?"
+        );
         $self->{resolver} = RT::URI::base->new( $self->CurrentUser ); # clear resolver
     	return (undef);
     }
@@ -153,9 +155,7 @@ sub FromURI {
 
 }
 
-# }}}
 
-# {{{ _GetResolver
 
 =head2 _GetResolver <scheme>
 
@@ -185,9 +185,7 @@ sub _GetResolver {
 
 }
 
-# }}}
 
-# {{{ Scheme
 
 =head2 Scheme
 
@@ -201,8 +199,6 @@ sub Scheme {
     return ($self->Resolver->Scheme);
 
 }
-# }}}
-# {{{ URI
 
 =head2 URI
 
@@ -216,9 +212,7 @@ sub URI {
     return ($self->Resolver->URI);
 
 }
-# }}}
 
-# {{{ Object
 
 =head2 Object
 
@@ -234,9 +228,7 @@ sub Object {
 }
 
 
-# }}}
 
-# {{{ IsLocal
 
 =head2 IsLocal
 
@@ -250,7 +242,6 @@ sub IsLocal {
 }
 
 
-# }}}
 
 =head2 AsHREF
 
@@ -275,9 +266,6 @@ sub Resolver {
     return ($self->{'resolver'});
 }
 
-eval "require RT::URI_Vendor";
-die $@ if ($@ && $@ !~ qr{^Can't locate RT/URI_Vendor.pm});
-eval "require RT::URI_Local";
-die $@ if ($@ && $@ !~ qr{^Can't locate RT/URI_Local.pm});
+RT::Base->_ImportOverlays();
 
 1;
