@@ -579,8 +579,9 @@ so that a better email address can be returned
 =cut
 
 sub SetEmailAddress {
-    my $self = shift;
+    my $self  = shift;
     my $Value = shift;
+    $Value = '' unless defined $Value;
 
     my ($val, $message) = $self->ValidateEmailAddress( $Value );
     if ( $val ) {
@@ -715,9 +716,9 @@ sub SetRandomPassword {
 
 Returns status, [ERROR or new password].  Resets this user's password to
 a randomly generated pronouncable password and emails them, using a
-global template called "RT_PasswordChange", which can be overridden
-with global templates "RT_PasswordChange_Privileged" or "RT_PasswordChange_NonPrivileged"
-for privileged and Non-privileged users respectively.
+global template called "PasswordChange".
+
+This function is currently unused in the UI, but available for local scripts.
 
 =cut
 
@@ -1319,6 +1320,30 @@ sub SetPreferences {
     }
 }
 
+=head2 Stylesheet
+
+Returns a list of valid stylesheets take from preferences.
+
+=cut
+
+sub Stylesheet {
+    my $self = shift;
+
+    my $style = RT->Config->Get('WebDefaultStylesheet', $self->CurrentUser);
+
+
+    my @css_paths = map { $_ . '/NoAuth/css' } RT::Interface::Web->ComponentRoots;
+
+    for my $css_path (@css_paths) {
+        if (-d "$css_path/$style") {
+            return $style
+        }
+    }
+
+    # Fall back to the system stylesheet.
+    return RT->Config->Get('WebDefaultStylesheet');
+}
+
 =head2 WatchedQueues ROLE_LIST
 
 Returns a RT::Queues object containing every queue watched by the user.
@@ -1568,7 +1593,7 @@ sub SetPrivateKey {
     );
     return ($status, $self->loc("Couldn't set private key"))
         unless $status;
-    return ($status, $self->loc("Unset private key"));
+    return ($status, $self->loc("Set private key"));
 }
 
 sub BasicColumns {
