@@ -62,9 +62,9 @@ configured as aliases for F<rt-mailgate>.
 
 =cut
 
-Set($CorrespondAddress, "");
+Set($CorrespondAddress, '');
 
-Set($CommentAddress, "");
+Set($CommentAddress, '');
 
 =item C<$WebDomain>
 
@@ -228,6 +228,14 @@ From lowest to highest priority, the levels are:
 
     debug info notice warning error critical alert emergency
 
+Many syslogds are configured to discard or file debug messages away, so
+if you're attempting to debug RT you may need to reconfigure your
+syslogd or use one of the other logging options.
+
+Logging to your screen affects scripts run from the command line as well
+as the STDERR sent to your webserver (so these logs will usually show up
+in your web server's error logs).
+
 =cut
 
 Set($LogToSyslog, "info");
@@ -235,13 +243,15 @@ Set($LogToScreen, "info");
 
 =item C<$LogToFile>, C<$LogDir>, C<$LogToFileNamed>
 
-Logging to a standalone file is also possible, but note that the file
-should needs to both exist and be writable by all direct users of the
-RT API.  This generally includes the web server and whoever
-rt-crontool runs as.  Note that rt-mailgate and the RT CLI go through
-the webserver, so their users do not need to have write permissions to
-this file. If you expect to have multiple users of the direct API,
-Best Practical recommends using syslog instead of direct file logging.
+Logging to a standalone file is also possible. The file needs to both
+exist and be writable by all direct users of the RT API. This generally
+includes the web server and whoever rt-crontool runs as. Note that
+rt-mailgate and the RT CLI go through the webserver, so their users do
+not need to have write permissions to this file. If you expect to have
+multiple users of the direct API, Best Practical recommends using syslog
+instead of direct file logging.
+
+You should set C<$LogToFile> to one of the levels documented above.
 
 =cut
 
@@ -313,7 +323,7 @@ should I<not> be an address that's managed by your RT instance.
 
 =cut
 
-Set($OwnerEmail, "root");
+Set($OwnerEmail, 'root');
 
 =item C<$LoopsToRTOwner>
 
@@ -657,7 +667,7 @@ then C<$OwnerEmail> will be used.
 
 =cut
 
-Set($DashboardAddress, "");
+Set($DashboardAddress, '');
 
 =item C<$DashboardSubject>
 
@@ -835,9 +845,13 @@ Set(@CustomFieldValuesSources, ());
 
 =item C<$CanonicalizeRedirectURLs>
 
-Set C<$CanonicalizeRedirectURLs> to 1 to use $C<WebURL> when
+Set C<$CanonicalizeRedirectURLs> to 1 to use C<$WebURL> when
 redirecting rather than the one we get from C<%ENV>.
 
+Apache's UseCanonicalName directive changes the hostname that RT
+finds in C<%ENV>.  You can read more about what turning it On or Off
+means in the documentation for your version of Apache.
+
 If you use RT behind a reverse proxy, you almost certainly want to
 enable this option.
 
@@ -856,7 +870,6 @@ Set(@JSFiles, qw/
     jquery-1.4.2.min.js
     jquery_noconflict.js
     jquery-ui-1.8.4.custom.min.js
-    jquery.tablesorter.min.js
     jquery-ui-patch-datepicker.js
     ui.timepickr.js
     titlebox-state.js
@@ -872,12 +885,12 @@ Set(@JSFiles, qw/
 
 =item C<$JSMinPath>
 
-Path to the jsmin binary, available from
-http://www.crockford.com/javascript/jsmin.html
+Path to the jsmin binary; if specified, it will be used to minify
+C<JSFiles>.  The default, and the fallback if the binary cannot be
+found, is to simply concatenate the files.
 
-If specified, it will be used to minify C<JSFiles>.  If it cannot be
-found, RT will fall back to the L<JavaScript::Minifier> module;
-failing that, RT will will simply concatenate the files.
+jsmin can be installed by running 'make jsmin' from the RT install
+directory, or from http://www.crockford.com/javascript/jsmin.html
 
 =cut
 
@@ -1040,7 +1053,7 @@ RT stores dates using the UTC timezone in the DB, so charts grouped by
 dates and time are not representative. Set C<$ChartsTimezonesInDB> to 1
 to enable timezone conversions using your DB's capabilities. You may
 need to do some work on the DB side to use this feature, read more in
-F<docs/timezones_in_charts.pod>.
+F<docs/customizing/timezones_in_charts.pod>.
 
 At this time, this feature only applies to MySQL and PostgreSQL.
 
@@ -1170,50 +1183,25 @@ Set($DefaultSelfServiceSearchResultFormat, qq{
 
 =item C<%FullTextSearch>
 
-Full text search (FTS) without indexes is a very slow operation and by
-default is disabled at all. To enable FTS set key 'Enable' to 1.
+Full text search (FTS) without database indexing is a very slow
+operation, and is thus disabled by default.
 
-Setup of indexes and filling them with data requires additional steps
-that vary from DB to DB. Use F<sbin/rt-setup-fulltext-index> helper
-for quick start. This script creates required structures in the DB and
-gives some ideas on next steps. Use F<sbin/rt-fulltext-indexer> to
-keep the index in sync.
+Before setting C<Indexed> to 1, read F<docs/full_text_indexing.pod> for
+the full details of FTS on your particular database.
+
+It is possible to enable FTS without database indexing support, simply
+by setting the C<Enable> key to 1, while leaving C<Indexed> set to 0.
+This is not generally suggested, as unindexed full-text searching can
+cause severe performance problems.
 
 =cut
 
 Set(%FullTextSearch,
     Enable  => 0,
     Indexed => 0,
-#    Table   => 'AttachmentsIndex',
-#    Column  => 'ftsindex',
 );
 
 
-=item C<$DontSearchFileAttachments>
-
-This refers to F<sbin/rt-setup-fulltext-index>.
-
-If C<$DontSearchFileAttachments> is set to 1, then uploaded files
-(attachments with file names) are not indexed.
-
-=cut
-
-Set($DontSearchFileAttachments, undef);
-
-=item C<$DontSearchBinaryAttachments>
-
-This refers to F<sbin/rt-setup-fulltext-index>.
-
-By default, text attachments are always indexed, and a known set of
-binary attachments are always skipped.
-
-If C<$DontSearchBinaryAttachments> is set to 1, then unrecognized binary
-data types will not be indexed.
-
-=cut
-
-Set($DontSearchBinaryAttachments, undef);
-
 =item C<$OnlySearchActiveTicketsInSimpleSearch>
 
 When query in simple search doesn't have status info, use this to only
@@ -1267,6 +1255,9 @@ extra information about the user, this expects a Format string of user
 attributes.  Please note that not all the attributes are supported in
 this display because we're not building a table.
 
+Example:
+C<Set($MoreAboutRequestorExtraInfo,"Organization, Address1")>
+
 =cut
 
 Set($MoreAboutRequestorExtraInfo, "");
@@ -1694,10 +1685,20 @@ Set($RedistributeAutoGeneratedMessages, "privileged");
 
 Should rejection notes from approvals be sent to the requestors?
 
+=back
+
 =cut
 
 Set($ApprovalRejectionNotes, 1);
 
+=head1 Extra security
+
+=over 4
+
+This is a list of extra security measures to enable that help keep your RT
+safe.  If you don't know what these mean, you should almost certainly leave the
+defaults alone.
+
 =item C<$DisallowExecuteCode>
 
 If set to a true value, the C<ExecuteCode> right will be removed from
@@ -1709,12 +1710,18 @@ be allowed to run arbitrary Perl code on the server via scrips.
 
 Set($DisallowExecuteCode, 0);
 
+=item C<$Framebusting>
+
+If set to a false value, framekiller javascript will be disabled and the
+X-Frame-Options: DENY header will be suppressed from all responses.
+This disables RT's clickjacking protection.
+
+=cut
+
+Set($Framebusting, 1);
+
 =back
 
-
-
-
-
 =head1 Authorization and user configuration
 
 =over 4
@@ -1812,7 +1819,7 @@ Set($LogoutRefresh, 1);
 
 =item C<$WebSecureCookies>
 
-By default, RT's session cookie isn't marked as "secure" Some web
+By default, RT's session cookie isn't marked as "secure". Some web
 browsers will treat secure cookies more carefully than non-secure
 ones, being careful not to write them to disk, only sending them over
 an SSL secured connection, and so on. To enable this behavior, set
@@ -1836,9 +1843,6 @@ Set($MinimumPasswordLength, 5);
 =back
 
 
-
-
-
 =head1 Internationalization
 
 =over 4
@@ -1934,7 +1938,7 @@ Set($AmbiguousDayInFuture, 0);
 =item C<$DefaultTimeUnitsToHours>
 
 Use this to set the default units for time entry to hours instead of
-minutes.
+minutes.  Note that this only effects entry, not display.
 
 =cut
 
@@ -2096,19 +2100,19 @@ ticket creation>.
 
 =item on_merge
 
-When tickets are merged status of the ticket that merged is changed by
-force to this. It should be one of inactive statuses; 'resolved' or
-its equivalent is most probably the best candidate.
+When tickets are merged, the status of the ticket that was merged
+away is forced to this value.  It should be one of inactive statuses;
+'resolved' or its equivalent is most probably the best candidate.
 
 =item approved
 
-When an approval accepted status of depending tickets changed
-to this value.
+When an approval is accepted, the status of depending tickets will
+be changed to this value.
 
 =item denied
 
-When an approval denied status of depending tickets changed
-to this value.
+When an approval is denied, the status of depending tickets will
+be changed to this value.
 
 =back
 
@@ -2141,20 +2145,24 @@ above.
 =head3 Protecting status changes with rights
 
 A transition or group of transitions can be protected by a specific
-right.
-
-For example:
+right.  Additionally, you can name new right names, which will be added
+to the system to control that transition.  For example, if you wished to
+create a lesser right than ModifyTicket for rejecting tickets, you could
+write:
 
     default => {
         ...
         rights => {
             '* -> deleted'  => 'DeleteTicket',
             '* -> rejected' => 'RejectTicket',
-            '* -> *'        => 'ModifyTicketStatus',
+            '* -> *'        => 'ModifyTicket',
         },
         ...
     },
 
+This would create a new C<RejectTicket> right in the system which you
+could assign to whatever groups you choose.
+
 On the left hand side you can have the following variants:
 
     '<from> -> <to>'
@@ -2189,7 +2197,6 @@ Use the following format to define labels and actions of transitions:
 
     default => {
         ...
-        actions => {
         actions => [
             'new -> open'     => { label => 'Open it', update => 'Respond' },
             'new -> resolved' => { label => 'Resolve', update => 'Comment' },
@@ -2229,7 +2236,8 @@ For example:
 
 Unless there is an explicit mapping between statuses in two different
 lifecycles, you can not move tickets between queues with these
-lifecycles.  Such a mapping is defined as follows:
+lifecycles.  This is true even if the different lifecycles use the exact
+same set of statuses.  Such a mapping is defined as follows:
 
     __maps__ => {
         'from lifecycle -> to lifecycle' => {
@@ -2267,23 +2275,52 @@ Set(%Lifecycles,
         },
         rights => {
             '* -> deleted'  => 'DeleteTicket',
-            '* -> rejected' => 'ModifyTicket',
             '* -> *'        => 'ModifyTicket',
         },
         actions => [
-            'new -> open'      => { label => 'Open It',  update => 'Respond' },
-            'new -> resolved'  => { label => 'Resolve',  update => 'Comment' },
-            'new -> rejected'  => { label => 'Reject',   update => 'Respond' },
-            'new -> deleted'   => { label => 'Delete'                        },
+            'new -> open'      => {
+                label  => 'Open It', # loc
+                update => 'Respond',
+            },
+            'new -> resolved'  => {
+                label  => 'Resolve', # loc
+                update => 'Comment',
+            },
+            'new -> rejected'  => {
+                label  => 'Reject', # loc
+                update => 'Respond',
+            },
+            'new -> deleted'   => {
+                label  => 'Delete', # loc
+            },
 
-            'open -> stalled'  => { label => 'Stall',    update => 'Comment' },
-            'open -> resolved' => { label => 'Resolve',  update => 'Comment' },
-            'open -> rejected' => { label => 'Reject',   update => 'Respond' },
+            'open -> stalled'  => {
+                label  => 'Stall', # loc
+                update => 'Comment',
+            },
+            'open -> resolved' => {
+                label  => 'Resolve', # loc
+                update => 'Comment',
+            },
+            'open -> rejected' => {
+                label  => 'Reject', # loc
+                update => 'Respond',
+            },
 
-            'stalled -> open'  => { label => 'Open It'                       },
-            'resolved -> open' => { label => 'Re-open',  update => 'Comment' },
-            'rejected -> open' => { label => 'Re-open',  update => 'Comment' },
-            'deleted -> open'  => { label => 'Undelete'                      },
+            'stalled -> open'  => {
+                label  => 'Open It', # loc
+            },
+            'resolved -> open' => {
+                label  => 'Re-open', # loc
+                update => 'Comment',
+            },
+            'rejected -> open' => {
+                label  => 'Re-open', # loc
+                update => 'Comment',
+            },
+            'deleted -> open'  => {
+                label  => 'Undelete', # loc
+            },
         ],
     },
 # don't change lifecyle of the approvals, they are not capable to deal with
@@ -2315,19 +2352,49 @@ Set(%Lifecycles,
             '* -> *'        => 'ModifyTicket',
         },
         actions => [
-            'new -> open'      => { label => 'Open It',  update => 'Respond' },
-            'new -> resolved'  => { label => 'Resolve',  update => 'Comment' },
-            'new -> rejected'  => { label => 'Reject',   update => 'Respond' },
-            'new -> deleted'   => { label => 'Delete'                        },
+            'new -> open'      => {
+                label  => 'Open It', # loc
+                update => 'Respond',
+            },
+            'new -> resolved'  => {
+                label  => 'Resolve', # loc
+                update => 'Comment',
+            },
+            'new -> rejected'  => {
+                label  => 'Reject', # loc
+                update => 'Respond',
+            },
+            'new -> deleted'   => {
+                label  => 'Delete', # loc
+            },
 
-            'open -> stalled'  => { label => 'Stall',    update => 'Comment' },
-            'open -> resolved' => { label => 'Resolve',  update => 'Comment' },
-            'open -> rejected' => { label => 'Reject',   update => 'Respond' },
+            'open -> stalled'  => {
+                label  => 'Stall', # loc
+                update => 'Comment',
+            },
+            'open -> resolved' => {
+                label  => 'Resolve', # loc
+                update => 'Comment',
+            },
+            'open -> rejected' => {
+                label  => 'Reject', # loc
+                update => 'Respond',
+            },
 
-            'stalled -> open'  => { label => 'Open It'                       },
-            'resolved -> open' => { label => 'Re-open',  update => 'Comment' },
-            'rejected -> open' => { label => 'Re-open',  update => 'Comment' },
-            'deleted -> open'  => { label => 'Undelete'                      },
+            'stalled -> open'  => {
+                label  => 'Open It', # loc
+            },
+            'resolved -> open' => {
+                label  => 'Re-open', # loc
+                update => 'Comment',
+            },
+            'rejected -> open' => {
+                label  => 'Re-open', # loc
+                update => 'Comment',
+            },
+            'deleted -> open'  => {
+                label  => 'Undelete', # loc
+            },
         ],
     },
 );
@@ -2388,8 +2455,13 @@ Set(%AdminSearchResultFormat,
         .q{,__AppliedTo__, __FriendlyType__, __FriendlyPattern__},
 
     Scrips =>
-        q{'<a href="__WebPath__/__WebRequestPathDir__/Scrip.html?id=__id__&Queue=__QueueId__">__id__</a>/TITLE:#'}
-        .q{,'<a href="__WebPath__/__WebRequestPathDir__/Scrip.html?id=__id__&Queue=__QueueId__">__Description__</a>/TITLE:Description'}
+        q{'<a href="__WebPath__/Admin/Queues/Scrip.html?id=__id__&Queue=__QueueId__">__id__</a>/TITLE:#'}
+        .q{,'<a href="__WebPath__/Admin/Queues/Scrip.html?id=__id__&Queue=__QueueId__">__Description__</a>/TITLE:Description'}
+        .q{,__Stage__, __Condition__, __Action__, __Template__},
+
+    GlobalScrips =>
+        q{'<a href="__WebPath__/Admin/Global/Scrip.html?id=__id__">__id__</a>/TITLE:#'}
+        .q{,'<a href="__WebPath__/Admin/Global/Scrip.html?id=__id__">__Description__</a>/TITLE:Description'}
         .q{,__Stage__, __Condition__, __Action__, __Template__},
 
     Templates =>
@@ -2480,6 +2552,9 @@ RT has rudimentary SQL statement logging support; simply set
 C<$StatementLog> to be the level that you wish SQL statements to be
 logged at.
 
+Enabling this option will also expose the SQL Queries page in the
+Configuration -> Tools menu for SuperUsers.
+
 =cut
 
 Set($StatementLog, undef);
@@ -2508,8 +2583,6 @@ Set($LinkTransactionsRun1Scrip, 0);
 This option has been deprecated.  You can configure this site-wide
 with L</Lifecycles> (see L</Labeling and defining actions>).
 
-=back
-
 =cut
 
 1;
